---
title: <span class="badge object-type-scalar"></span> KibibitsPerSecond
---
# <span class="badge object-type-scalar"></span> KibibitsPerSecond

Data rate: kibibits/sec

## Definition

```python
# Data rate: kibibits/sec
KibibitsPerSecond: typing.Literal["Kibits"] = "Kibits"
```
